from rest_framework import serializers
from phonenumbers import NumberParseException, parse, PhoneNumberFormat
from phonenumber_field.phonenumber import PhoneNumber


class PhoneNumberField(serializers.Field):
    number_format = PhoneNumberFormat.NATIONAL

    def __init__(self, number_format=None, *args, **kwargs):
        self.number_format = number_format or self.number_format
        super(PhoneNumberField, self).__init__(*args, **kwargs)

    def to_representation(self, value):
        if not isinstance(value, PhoneNumber):
            try:
                value = parse(value, numobj=PhoneNumber())
            except (NumberParseException, TypeError):
                return value

        return value.format_as(self.number_format).replace(' ', '')

    def to_internal_value(self, data):
        return str(data)



import subprocess
from io import StringIO

from django.core.management import call_command
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'makes and compiles message files'

    FAIL_MESSAGES = [
        'warning: \'msgid\' format string with unnamed arguments cannot be properly localized',
        'warning: Empty msgid.  It is reserved by GNU gettext',
    ]

    def add_arguments(self, parser):
        parser.add_argument('--fail', action='store_true')

    def handle(self, *args, **options):
        self.stdout.write('Making messages')
        out = StringIO()
        call_command('makemessages', locale=['de'], no_location=True, no_obsolete=True, ignore=['docs/*'],
                     extension=['html', 'py', 'txt', 'js', 'tex'], stdout=out)

        self.stdout.write(out.getvalue())

        if options['fail'] and any(x in out.getvalue() for x in self.FAIL_MESSAGES):
            self.stderr.write('Some fail messages were encountered')
            exit(1)

        subprocess.call(["find", ".", "-type", "f", "-name", '*.po', "-exec",
                         "sed", "-i", "-n", "/POT-Creation-Date/!p", "{}", ";"])
        self.stdout.write('Compiling messages')
        call_command('compilemessages', locale=['de'])



__title__ = 'easys-ordermanager'
__description__ = 'API definition of RH order manager for EasyS'
__version__ = '1.4.32'
__url__ = 'https://github.com/RegioHelden/easys-ordermanager'
__author__ = 'Jens Nistler, Mounir Messelmeni'
__author_email__ = 'opensource@regiohelden.de'
__license__ = 'GPL 3'
